"""Team alchemy adapter re-exports for belgie consumers."""

_ALCHEMY_IMPORT_ERROR = (
    "belgie.alchemy.team requires the 'alchemy' and 'team' extras. Install with: uv add belgie[alchemy,team]"
)

try:
    from belgie_alchemy.team import TeamAdapter
except ModuleNotFoundError as exc:
    raise ImportError(_ALCHEMY_IMPORT_ERROR) from exc

__all__ = ["TeamAdapter"]



"""Core alchemy adapter re-exports for belgie consumers."""

_ALCHEMY_IMPORT_ERROR = "belgie.alchemy.core requires the 'alchemy' extra. Install with: uv add belgie[alchemy]"

try:
    from belgie_alchemy.core import BelgieAdapter
except ModuleNotFoundError as exc:
    raise ImportError(_ALCHEMY_IMPORT_ERROR) from exc

__all__ = ["BelgieAdapter"]



_OAUTH_CLIENT_IMPORT_ERROR = (
    "belgie.oauth.microsoft requires the 'oauth-client' extra. Install with: uv add belgie[oauth-client]"
)

try:
    from belgie_oauth import (  # type: ignore[import-not-found]
        MicrosoftOAuth,
        MicrosoftOAuthClient,
        MicrosoftOAuthPlugin,
        MicrosoftUserInfo,
    )
except ModuleNotFoundError as exc:
    raise ImportError(_OAUTH_CLIENT_IMPORT_ERROR) from exc

__all__ = [
    "MicrosoftOAuth",
    "MicrosoftOAuthClient",
    "MicrosoftOAuthPlugin",
    "MicrosoftUserInfo",
]



"""MCP re-exports for belgie consumers."""

_MCP_IMPORT_ERROR = "belgie.mcp requires the 'mcp' extra. Install with: uv add belgie[mcp]"

try:
    from belgie_mcp import (  # type: ignore[import-not-found]
        BelgieOAuthTokenVerifier,
        Mcp,
        McpPlugin,
        get_user_from_access_token,
    )
except ModuleNotFoundError as exc:
    raise ImportError(_MCP_IMPORT_ERROR) from exc

__all__ = [
    "BelgieOAuthTokenVerifier",
    "Mcp",
    "McpPlugin",
    "get_user_from_access_token",
]



"""Alchemy re-exports for belgie consumers."""

_ALCHEMY_IMPORT_ERROR = "belgie.alchemy requires the 'alchemy' extra. Install with: uv add belgie[alchemy]"

try:
    from belgie_alchemy.core import BelgieAdapter
    from belgie_alchemy.core.mixins import AccountMixin, OAuthStateMixin, SessionMixin, UserMixin
    from belgie_alchemy.organization.mixins import (
        OrganizationInvitationMixin,
        OrganizationMemberMixin,
        OrganizationMixin,
    )
    from belgie_alchemy.team.mixins import TeamMemberMixin, TeamMixin
except ModuleNotFoundError as exc:
    raise ImportError(_ALCHEMY_IMPORT_ERROR) from exc

__all__ = [
    "AccountMixin",
    "BelgieAdapter",
    "OAuthStateMixin",
    "OrganizationInvitationMixin",
    "OrganizationMemberMixin",
    "OrganizationMixin",
    "SessionMixin",
    "TeamMemberMixin",
    "TeamMixin",
    "UserMixin",
]



"""OAuth namespace package.

Use:
- `belgie.oauth.server` for OAuth server symbols
- `belgie.oauth.google` for Google OAuth client symbols
- `belgie.oauth.microsoft` for Microsoft OAuth client symbols
"""
